@@ -8,7 +8,6 @@ from struct import Struct, error
 from typing import Any, Iterable, Optional, Tuple, BinaryIO, Union, Iterator
 from urllib.parse import urlparse
 
-import numpy as np
 from osef import types
 
 
@@ -24,22 +23,23 @@ def open_osef(path: str) -> Union[BinaryIO, socket.socket, None]:
     parsed = urlparse(path)
     if path == "-":
         return sys.stdin.buffer
-    elif parsed.scheme == "tcp":
-        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+
+    if parsed.scheme == "tcp":
+        tcp_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         while True:
             try:
-                s.connect((parsed.hostname, parsed.port or 11120))
+                tcp_socket.connect((parsed.hostname, parsed.port or 11120))
                 break
             except ConnectionRefusedError:
                 continue
-        return s
-    else:
-        try:
-            f = open(path, "rb")
-            return f
-        except:
-            print(f"Cannot open file:{path}\n")
-            return None
+        return tcp_socket
+
+    try:
+        file = open(path, "rb")  # pylint: disable=consider-using-with
+        return file
+    except Exception:  # pylint: disable=broad-except
+        print(f"Cannot open file:{path}\n")
+        return None
 
 
 _Tlv = namedtuple("TLV", "type length value")
@@ -54,7 +54,7 @@ def iter_file(opened_file: BinaryIO) -> Iterator[_Tlv]:
     while True:
         try:
             frame_tlv = _read_next_tlv(opened_file)
-        except Exception:
+        except Exception:  # pylint: disable=broad-except
             print(
                 "Error: cannot read next Tlv from file (malformated Tlv?).\n"
                 + f"Details: {traceback.format_exc()}"
@@ -63,8 +63,8 @@ def iter_file(opened_file: BinaryIO) -> Iterator[_Tlv]:
             break
         if frame_tlv is None:
             break
-        else:
-            yield frame_tlv
+
+        yield frame_tlv
 
 
 def get_tlv_iterator(
@@ -74,13 +74,13 @@ def get_tlv_iterator(
 
     :param opened_file: opened binary file containing tlv frames.
     :param first: iterate only on N first frames of file.
-    :param last: iterate only on M last frames of file. Can be used with first to get the range (N-M)..N
+    :param last: iterate only on M last frames of file.
+    Can be used with first to get the range (N-M)..N
     :return: tlv frame iterator
     """
     if first is None and last is None:
         return enumerate(iter_file(opened_file))
-    else:
-        return deque(islice(enumerate(iter_file(opened_file)), first), last)
+    return deque(islice(enumerate(iter_file(opened_file)), first), last)
 
 
 _TreeNode = namedtuple("TreeNode", "type children leaf_value")
@@ -104,8 +104,7 @@ def build_tree(tlv: _Tlv) -> _TreeNode:
             children.append(sub_tree)
             read += sub_size
         return _TreeNode(tlv.type, children, None)
-    else:
-        return _TreeNode(tlv.type, None, tlv.value)
+    return _TreeNode(tlv.type, None, tlv.value)
 
 
 def unpack_value(value: bytes, leaf_info: types.LeafInfo) -> Any:
@@ -116,39 +115,11 @@ def unpack_value(value: bytes, leaf_info: types.LeafInfo) -> Any:
     :return: python object
     """
     try:
-        if leaf_info.leaf_type == types.LeafType.Value:
-            pack_format = leaf_info.format_info
-            return (Struct(pack_format).unpack(value))[0]
 
-        elif leaf_info.leaf_type == types.LeafType.Array:
-            dtype = leaf_info.format_info
-            return np.frombuffer(value, dtype=dtype)
-
-        elif leaf_info.leaf_type == types.LeafType.Bytes:
-            return value
-
-        elif leaf_info.leaf_type == types.LeafType.StructuredArray:
-            dtype = leaf_info.format_info
-            array = np.frombuffer(value, dtype=dtype)
-            names = array.dtype.names
-            if "__todrop" in names:
-                names.remove("__todrop")
-                array = array[names]
-            return array
-
-        elif leaf_info.leaf_type == types.LeafType.Dict:
-            pack_format, fields_name = leaf_info.format_info
-            array = list(Struct(pack_format).iter_unpack(value))
-            return dict(zip(fields_name, array[0]))
-
-        elif leaf_info.leaf_type == types.LeafType.String:
-            return value.decode("ascii")[:-1]
-
-        elif leaf_info.leaf_type == types.LeafType.Custom:
-            return leaf_info.format_info(value)
-
-        else:  # including LeafType.Unknown
-            return value
+        if leaf_info.parsing_function is not None:
+            return leaf_info.parsing_function(value)
+        # unknown parser
+        return value
 
     except error:
         return value
@@ -171,18 +142,19 @@ def parse(
 
     :param path: path to osef file or TCP stream if path has form *tcp://hostname:port*
     :param first: iterate only on N first frames of file.
-    :param last: iterate only on M last frames of file. Can be used with first to get the range (N-M)..N
+    :param last: iterate only on M last frames of file.
+    Can be used with first to get the range (N-M)..N
     :return: next tlv dictionary
     """
-    f = open_osef(path)
-    if not f:
+    osef_io = open_osef(path)
+    if not osef_io:
         raise FileNotFoundError(f"Can't open file/stream from provided path: {path}")
-    iterator = get_tlv_iterator(f, first, last)
-    for idx, tlv in iterator:
+    iterator = get_tlv_iterator(osef_io, first, last)
+    for _, tlv in iterator:
         raw_tree = build_tree(tlv)
         if raw_tree:
             yield parse_to_dict(raw_tree)
-    f.close()
+    osef_io.close()
 
 
 # -- Tlv Parsing --
@@ -198,19 +170,19 @@ _STRUCT_FORMAT += "%ds"  # buffer of fixed size (field 'V' ie. 'Value')
 def _align_size(size: int) -> int:
     """Returned aligned size from tlv size"""
     alignment_size = 4
-    n = size % alignment_size
-    return size if n == 0 else size + alignment_size - n
+    offset = size % alignment_size
+    return size if offset == 0 else size + alignment_size - offset
 
 
 # Add read method to socket to get same API as file
 setattr(socket.socket, "read", lambda self, size=4096: self.recv(size))
 
 
-def _read_from_file(f: BinaryIO, n: int) -> bytes:
+def _read_from_file(osef_io: BinaryIO, byte_number: int) -> bytes:
     """Read given number of bytes from readable stream"""
     blob = b""
-    while len(blob) < n:
-        blob_inc = f.read(n - len(blob))
+    while len(blob) < byte_number:
+        blob_inc = osef_io.read(byte_number - len(blob))
 
         # End of file
         if blob_inc is None or len(blob_inc) == 0:
@@ -221,12 +193,12 @@ def _read_from_file(f: BinaryIO, n: int) -> bytes:
     return blob
 
 
-def _read_next_tlv(f: BinaryIO) -> Optional[_Tlv]:
+def _read_next_tlv(osef_io: BinaryIO) -> Optional[_Tlv]:
     """Read the next TLV from a binary stream (file or socket)"""
     # Read header
     struct = Struct(_STRUCT_FORMAT % 0)
     try:
-        blob = _read_from_file(f, struct.size)
+        blob = _read_from_file(osef_io, struct.size)
     except EOFError:
         return None
 
@@ -235,7 +207,7 @@ def _read_next_tlv(f: BinaryIO) -> Optional[_Tlv]:
 
     # Now that we know its length we can read the Value
     struct = Struct(_STRUCT_FORMAT % read_tlv.length)
-    blob += _read_from_file(f, struct.size - len(blob))
+    blob += _read_from_file(osef_io, struct.size - len(blob))
     read_tlv = _Tlv._make(struct.unpack_from(blob))
 
     return read_tlv
@@ -259,10 +231,10 @@ def _parse_tlv_from_blob(blob: bytes, offset=0) -> Tuple[_Tlv, int]:
 
 def _parse_raw_to_tuple(raw_tree: _TreeNode) -> Tuple[str, Any]:
     """Parse a raw TLV tree, using OSEF types"""
-    t, children, leaf_value = raw_tree
+    osef_type, children, leaf_value = raw_tree
 
     # Get leaf type info
-    type_info = types.outsight_type_info(t)
+    type_info = types.get_type_info_by_id(osef_type)
 
     # For leaves or unknown, return value
     if isinstance(type_info.node_info, types.LeafInfo):
@@ -270,12 +242,12 @@ def _parse_raw_to_tuple(raw_tree: _TreeNode) -> Tuple[str, Any]:
 
     # For non-leaves, add each children to a dictionary
     tree = {}
-    zone_list = []
+    children_list = []
     for child in children:
         child_name, child_tree = _parse_raw_to_tuple(child)
         if type_info.node_info.type == list:
-            zone_list.append(child_tree)
-            tree = zone_list
+            children_list.append({child_name: child_tree})
+            tree = children_list
         elif type_info.node_info.type == dict:
             tree[child_name] = child_tree
         else:
